@@ -6,9 +6,10 @@ their relations.
 
 
 import argparse
-from . import compare
-from .lcs import edit, lcs_graph, maximal_variant, to_dot, traversal
-from .utils import random_sequence, random_variants
+from .lcs import edit, lcs_graph, to_dot, traversal
+from .relations.sequence_based import compare
+from .relations.supremal_based import spanning_variant
+from .utils import fasta_sequence, random_sequence, random_variants
 from .variants import Parser, patch, to_hgvs
 
 
@@ -32,16 +33,16 @@ def main():
 
     lhs_group = compare_parser.add_mutually_exclusive_group()
     lhs_group.add_argument("--lhs", type=str, help="an observed sequence as string (lhs)")
-    lhs_group.add_argument("--lhs-hgvs", type=str, help="an HGVS variant (lhs)")
-    lhs_group.add_argument("--lhs-spdi", type=str, help="a SPDI variant (lhs)")
+    lhs_group.add_argument("--lhs-hgvs", type=str, help="a variant in HGVS (lhs)")
+    lhs_group.add_argument("--lhs-spdi", type=str, help="a variant in SPDI (lhs)")
     lhs_group.add_argument("--lhs-file", type=str, help="an observed sequence from a file (lhs)")
     lhs_group.add_argument("--lhs-random-variant", action="store_true", help="a random variant")
     lhs_group.add_argument("--lhs-random-sequence", action="store_true", help="a random sequence (default)")
 
     rhs_group = compare_parser.add_mutually_exclusive_group()
     rhs_group.add_argument("--rhs", type=str, help="an observed sequence as string (rhs)")
-    rhs_group.add_argument("--rhs-hgvs", type=str, help="an HGVS variant (rhs)")
-    rhs_group.add_argument("--rhs-spdi", type=str, help="a SPDI variant (rhs)")
+    rhs_group.add_argument("--rhs-hgvs", type=str, help="a variant in HGVS (rhs)")
+    rhs_group.add_argument("--rhs-spdi", type=str, help="a variant in SPDI (rhs)")
     rhs_group.add_argument("--rhs-file", type=str, help="an observed sequence from a file (rhs)")
     rhs_group.add_argument("--rhs-random-variant", action="store_true", help="a random variant")
     rhs_group.add_argument("--rhs-random-sequence", action="store_true", help="a random sequence (default)")
@@ -51,12 +52,12 @@ def main():
     extract_parser.add_argument("--atomics", action="store_true", help="only deletions and insertions")
     extract_parser.add_argument("--distance", action="store_true", help="output simple edit distance")
     extract_parser.add_argument("--dot", action="store_true", help="output Graphviz DOT")
-    extract_parser.add_argument("--max-variant", action="store_true", help="output maximal variant")
+    extract_parser.add_argument("--supremal-variant", action="store_true", help="output supremal variant")
 
     observed_group = extract_parser.add_mutually_exclusive_group()
     observed_group.add_argument("--observed", type=str, help="an observed sequence as string")
-    observed_group.add_argument("--observed-hgvs", type=str, help="an HGVS variant")
-    observed_group.add_argument("--observed-spdi", type=str, help="a SPDI variant")
+    observed_group.add_argument("--observed-hgvs", type=str, help="a variant in HGVS")
+    observed_group.add_argument("--observed-spdi", type=str, help="a variant in SPDI")
     observed_group.add_argument("--observed-file", type=str, help="an observed sequence from a file")
     observed_group.add_argument("--observed-random-variant", action="store_true", help="a random variant")
     observed_group.add_argument("--observed-random-sequence", action="store_true", help="a random sequence (default)")
@@ -77,7 +78,7 @@ def main():
         reference = args.reference
     elif args.reference_file is not None:
         with open(args.reference_file, encoding="utf-8") as file:
-            reference = file.read().strip()
+            reference = fasta_sequence(file.readlines())
     else:  # args.reference_random_sequence
         reference = random_sequence(args.random_sequence_max, args.random_sequence_min)
         print(reference)
@@ -86,16 +87,16 @@ def main():
         if args.lhs is not None:
             lhs = args.lhs
         elif args.lhs_hgvs is not None:
-            lhs = patch(reference, Parser(args.lhs_hgvs).hgvs())
+            lhs = patch(reference, Parser(args.lhs_hgvs).hgvs(reference))
         elif args.lhs_spdi is not None:
             lhs = patch(reference, Parser(args.lhs_spdi).spdi())
         elif args.lhs_file is not None:
             with open(args.lhs_file, encoding="utf-8") as file:
-                lhs = file.read().strip()
+                lhs = fasta_sequence(file.readlines())
         elif args.lhs_random_variant:
             variants = list(random_variants(reference, args.random_variant_p))
             lhs = patch(reference, variants)
-            print(to_hgvs(variants, reference, sequence_prefix=False))
+            print(to_hgvs(variants, reference))
         else:  # args.lhs_random_sequence:
             lhs = random_sequence(args.random_sequence_max, args.random_sequence_min)
             print(lhs)
@@ -103,16 +104,16 @@ def main():
         if args.rhs is not None:
             rhs = args.rhs
         elif args.rhs_hgvs is not None:
-            rhs = patch(reference, Parser(args.rhs_hgvs).hgvs())
+            rhs = patch(reference, Parser(args.rhs_hgvs).hgvs(reference))
         elif args.rhs_spdi is not None:
             rhs = patch(reference, Parser(args.rhs_spdi).spdi())
         elif args.rhs_file is not None:
             with open(args.rhs_file, encoding="utf-8") as file:
-                rhs = file.read().strip()
+                rhs = fasta_sequence(file.readlines())
         elif args.rhs_random_variant:
             variants = list(random_variants(reference, args.random_variant_p))
             rhs = patch(reference, variants)
-            print(to_hgvs(variants, reference, sequence_prefix=False))
+            print(to_hgvs(variants, reference))
         else:  # args.rhs_random_sequence
             rhs = random_sequence(args.random_sequence_max, args.random_sequence_min)
             print(rhs)
@@ -123,16 +124,16 @@ def main():
         if args.observed is not None:
             observed = args.observed
         elif args.observed_hgvs is not None:
-            observed = patch(reference, Parser(args.observed_hgvs).hgvs())
+            observed = patch(reference, Parser(args.observed_hgvs).hgvs(reference))
         elif args.observed_spdi is not None:
             observed = patch(reference, Parser(args.observed_spdi).spdi())
         elif args.observed_file is not None:
             with open(args.observed_file, encoding="utf-8") as file:
-                observed = file.read().strip()
+                observed = fasta_sequence(file.readlines())
         elif args.observed_random_variant:
             variants = list(random_variants(reference, args.random_variant_p))
             observed = patch(reference, variants)
-            print(to_hgvs(variants, reference, sequence_prefix=False))
+            print(to_hgvs(variants, reference))
         else:  # args.observed_random_sequence
             observed = random_sequence(args.random_sequence_max, args.random_sequence_min)
             print(observed)
@@ -144,21 +145,21 @@ def main():
             print(distance)
         if args.dot:
             print(to_dot(reference, root))
-        if args.max_variant:
-            max_variant = maximal_variant(reference, observed, edges)
-            print(max_variant.to_hgvs(reference))
+        if args.supremal_variant:
+            variant = spanning_variant(reference, observed, edges)
+            print(variant.to_hgvs(reference), variant)
         if True or args.all:
             for variants in traversal(root, args.atomics):
-                print(to_hgvs(variants, reference, sequence_prefix=False))
+                print(to_hgvs(variants, reference))
 
     elif args.command == "patch":
         if args.hgvs is not None:
-            variants = Parser(args.hgvs).hgvs()
+            variants = Parser(args.hgvs).hgvs(reference)
         elif args.spdi is not None:
             variants = Parser(args.spdi).spdi()
         else:  # args.random_variant
             variants = list(random_variants(reference, args.random_variant_p))
-            print(to_hgvs(variants, reference, sequence_prefix=False))
+            print(to_hgvs(variants, reference))
 
         print(patch(reference, variants))
 
