@@ -20,7 +20,6 @@ pp. 317-323.
 """
 
 
-from operator import attrgetter
 from ..variants import Variant, to_hgvs
 
 
@@ -39,7 +38,8 @@ class _Node:
         self.incoming = 0
 
     def __eq__(self, other):
-        return self.row == other.row and self.col == other.col and self.length == other.length
+        return (self.row == other.row and self.col == other.col and
+                self.length == other.length)
 
     def __hash__(self):
         return hash((self.row, self.col, self.length))
@@ -259,23 +259,6 @@ def lcs_graph(reference, observed, lcs_nodes):
     return source, edges
 
 
-def maximal_variant(reference, observed, variants):
-    """Calculate the maximal spanning variant for a collection of variants.
-
-    Raises
-    ------
-    ValueError
-        If no variants are present.
-    """
-
-    if not variants:
-        raise ValueError("No variants")
-
-    start = min(variants, key=attrgetter("start")).start
-    end = max(variants, key=attrgetter("end")).end
-    return Variant(start, end, observed[start:len(observed) - (len(reference) - end)])
-
-
 def traversal(root, atomics=False):
     """Traverse the LCS graph.
 
@@ -313,18 +296,17 @@ def traversal(root, atomics=False):
 
 def to_dot(reference, root):
     """The LCS graph in Graphviz DOT format."""
-
-    def nodes_and_edges():
+    def traverse():
         # breadth-first traversal
-        queue = [root]
         visited = {root}
+        queue = [root]
         while queue:
             node = queue.pop(0)
-            yield f'"{node.row}_{node.col}" [label="{node.row, node.col}"];'
             for succ, variant in node.edges:
-                yield f'"{node.row}_{node.col}" -> "{succ.row}_{succ.col}" [label="{to_hgvs(variant, reference, sequence_prefix=False)}"];'
+                yield (f'"{node.row}_{node.col}" -> "{succ.row}_{succ.col}"'
+                       f' [label="{to_hgvs(variant, reference)}"];')
                 if succ not in visited:
                     visited.add(succ)
                     queue.append(succ)
 
-    return "digraph {\n    " + "\n    ".join(nodes_and_edges()) + "\n}"
+    return "digraph {\n    " + "\n    ".join(traverse()) + "\n}"
